@@ -1,6 +1,6 @@
 use std::sync::mpsc::channel;
 
-pub fn main() {
+fn main() {
     let (tx, rx) = channel::<Box<_>>();
     tx.send(Box::new(100)).unwrap();
     let v = rx.recv().unwrap();
